;; Generated package description from dape.el  -*- no-byte-compile: t -*-
(define-package "dape" "0.19.0.0.20241229.225058" "Debug Adapter Protocol for Emacs" '((emacs "29.1") (jsonrpc "1.0.25")) :commit "a8cb4c0557131136233950383308022ff4af3f73" :maintainer '("Daniel Pettersson" . "daniel@dpettersson.net") :url "https://github.com/svaante/dape")
